==> parcel-bundler-vue-1.6.3.tgz: package/lib/FSCache.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = require('./utils/fs');
var path = require('path');
var md5 = require('./utils/md5');
var objectHash = require('./utils/objectHash');
var pkg = require('../package.json');
var logger = require('./Logger');

// These keys can affect the output, so if they differ, the cache should not match
var OPTION_KEYS = ['publicURL', 'minify', 'hmr', 'target'];

var FSCache = function () {
  function FSCache(options) {
    (0, _classCallCheck3.default)(this, FSCache);

    this.dir = path.resolve(options.cacheDir || '.cache');
    this.dirExists = false;
    this.invalidated = new _set2.default();
    this.optionsHash = objectHash(OPTION_KEYS.reduce(function (p, k) {
      return p[k] = options[k], p;
    }, {
      version: pkg.version
    }));
  }

  (0, _createClass3.default)(FSCache, [{
    key: 'ensureDirExists',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return fs.mkdirp(this.dir);

              case 2:
                this.dirExists = true;

              case 3:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function ensureDirExists() {
        return _ref.apply(this, arguments);
      }

      return ensureDirExists;
    }()
  }, {
    key: 'getCacheFile',
    value: function getCacheFile(filename) {
      var hash = md5(this.optionsHash + filename);
      return path.join(this.dir, hash + '.json');
    }
  }, {
    key: 'writeDepMtimes',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(data) {
        var _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, dep, stats;

        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                // Write mtimes for each dependent file that is already compiled into this asset
                _iteratorNormalCompletion = true;
                _didIteratorError = false;
                _iteratorError = undefined;
                _context2.prev = 3;
                _iterator = (0, _getIterator3.default)(data.dependencies);

              case 5:
                if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
                  _context2.next = 15;
                  break;
                }

                dep = _step.value;

                if (!dep.includedInParent) {
                  _context2.next = 12;
                  break;
                }

                _context2.next = 10;
                return fs.stat(dep.name);

              case 10:
                stats = _context2.sent;

                dep.mtime = stats.mtime.getTime();

              case 12:
                _iteratorNormalCompletion = true;
                _context2.next = 5;
                break;

              case 15:
                _context2.next = 21;
                break;

              case 17:
                _context2.prev = 17;
                _context2.t0 = _context2['catch'](3);
                _didIteratorError = true;
                _iteratorError = _context2.t0;

              case 21:
                _context2.prev = 21;
                _context2.prev = 22;

                if (!_iteratorNormalCompletion && _iterator.return) {
                  _iterator.return();
                }

              case 24:
                _context2.prev = 24;

                if (!_didIteratorError) {
                  _context2.next = 27;
                  break;
                }

                throw _iteratorError;

              case 27:
                return _context2.finish(24);

              case 28:
                return _context2.finish(21);

              case 29:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this, [[3, 17, 21, 29], [22,, 24, 28]]);
      }));

      function writeDepMtimes(_x) {
        return _ref2.apply(this, arguments);
      }

      return writeDepMtimes;
    }()
  }, {
    key: 'write',
    value: function () {
      var _ref3 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3(filename, data) {
        return _regenerator2.default.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.prev = 0;
                _context3.next = 3;
                return this.ensureDirExists();

              case 3:
                _context3.next = 5;
                return this.writeDepMtimes(data);

              case 5:
                _context3.next = 7;
                return fs.writeFile(this.getCacheFile(filename), (0, _stringify2.default)(data));

              case 7:
                this.invalidated.delete(filename);
                _context3.next = 13;
                break;

              case 10:
                _context3.prev = 10;
                _context3.t0 = _context3['catch'](0);

                logger.error('Error writing to cache', _context3.t0);

              case 13:
              case 'end':
                return _context3.stop();
            }
          }
        }, _callee3, this, [[0, 10]]);
      }));

      function write(_x2, _x3) {
        return _ref3.apply(this, arguments);
      }

      return write;
    }()
  }, {
    key: 'checkDepMtimes',
    value: function () {
      var _ref4 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee4(data) {
        var _iteratorNormalCompletion2, _didIteratorError2, _iteratorError2, _iterator2, _step2, dep, stats;

        return _regenerator2.default.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                // Check mtimes for files that are already compiled into this asset
                // If any of them changed, invalidate.
                _iteratorNormalCompletion2 = true;
                _didIteratorError2 = false;
                _iteratorError2 = undefined;
                _context4.prev = 3;
                _iterator2 = (0, _getIterator3.default)(data.dependencies);

              case 5:
                if (_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done) {
                  _context4.next = 16;
                  break;
                }

                dep = _step2.value;

                if (!dep.includedInParent) {
                  _context4.next = 13;
                  break;
                }

                _context4.next = 10;
                return fs.stat(dep.name);

              case 10:
                stats = _context4.sent;

                if (!(stats.mtime > dep.mtime)) {
                  _context4.next = 13;
                  break;
                }

                return _context4.abrupt('return', false);

              case 13:
                _iteratorNormalCompletion2 = true;
                _context4.next = 5;
                break;

              case 16:
                _context4.next = 22;
                break;

              case 18:
                _context4.prev = 18;
                _context4.t0 = _context4['catch'](3);
                _didIteratorError2 = true;
                _iteratorError2 = _context4.t0;

              case 22:
                _context4.prev = 22;
                _context4.prev = 23;

                if (!_iteratorNormalCompletion2 && _iterator2.return) {
                  _iterator2.return();
                }

              case 25:
                _context4.prev = 25;

                if (!_didIteratorError2) {
                  _context4.next = 28;
                  break;
                }

                throw _iteratorError2;

              case 28:
                return _context4.finish(25);

              case 29:
                return _context4.finish(22);

              case 30:
                return _context4.abrupt('return', true);

              case 31:
              case 'end':
                return _context4.stop();
            }
          }
        }, _callee4, this, [[3, 18, 22, 30], [23,, 25, 29]]);
      }));

      function checkDepMtimes(_x4) {
        return _ref4.apply(this, arguments);
      }

      return checkDepMtimes;
    }()
  }, {
    key: 'read',
    value: function () {
      var _ref5 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee5(filename) {
        var cacheFile, stats, cacheStats, json, data;
        return _regenerator2.default.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                if (!this.invalidated.has(filename)) {
                  _context5.next = 2;
                  break;
                }

                return _context5.abrupt('return', null);

              case 2:
                cacheFile = this.getCacheFile(filename);
                _context5.prev = 3;
                _context5.next = 6;
                return fs.stat(filename);

              case 6:
                stats = _context5.sent;
                _context5.next = 9;
                return fs.stat(cacheFile);

              case 9:
                cacheStats = _context5.sent;

                if (!(stats.mtime > cacheStats.mtime)) {
                  _context5.next = 12;
                  break;
                }

                return _context5.abrupt('return', null);

              case 12:
                _context5.next = 14;
                return fs.readFile(cacheFile);

              case 14:
                json = _context5.sent;
                data = JSON.parse(json);
                _context5.next = 18;
                return this.checkDepMtimes(data);

              case 18:
                if (_context5.sent) {
                  _context5.next = 20;
                  break;
                }

                return _context5.abrupt('return', null);

              case 20:
                return _context5.abrupt('return', data);

              case 23:
                _context5.prev = 23;
                _context5.t0 = _context5['catch'](3);
                return _context5.abrupt('return', null);

              case 26:
              case 'end':
                return _context5.stop();
            }
          }
        }, _callee5, this, [[3, 23]]);
      }));

      function read(_x5) {
        return _ref5.apply(this, arguments);
      }

      return read;
    }()
  }, {
    key: 'invalidate',
    value: function invalidate(filename) {
      this.invalidated.add(filename);
    }
  }, {
    key: 'delete',
    value: function () {
      var _ref6 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee6(filename) {
        return _regenerator2.default.wrap(function _callee6$(_context6) {
          while (1) {
            switch (_context6.prev = _context6.next) {
              case 0:
                _context6.prev = 0;
                _context6.next = 3;
                return fs.unlink(this.getCacheFile(filename));

              case 3:
                this.invalidated.delete(filename);
                _context6.next = 8;
                break;

              case 6:
                _context6.prev = 6;
                _context6.t0 = _context6['catch'](0);

              case 8:
              case 'end':
                return _context6.stop();
            }
          }
        }, _callee6, this, [[0, 6]]);
      }));

      function _delete(_x6) {
        return _ref6.apply(this, arguments);
      }

      return _delete;
    }()
  }]);
  return FSCache;
}();

module.exports = FSCache;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/FSCache.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _set = require('babel-runtime/core-js/set');

var _set2 = _interopRequireDefault(_set);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = require('./utils/fs');
var path = require('path');
var md5 = require('./utils/md5');
var objectHash = require('./utils/objectHash');
var pkg = require('../package.json');

// These keys can affect the output, so if they differ, the cache should not match
var OPTION_KEYS = ['publicURL', 'minify', 'hmr'];

var FSCache = function () {
  function FSCache(options) {
    (0, _classCallCheck3.default)(this, FSCache);

    this.dir = path.resolve(options.cacheDir || '.cache');
    this.dirExists = false;
    this.invalidated = new _set2.default();
    this.optionsHash = objectHash(OPTION_KEYS.reduce(function (p, k) {
      return p[k] = options[k], p;
    }, {
      version: pkg.version
    }));
  }

  (0, _createClass3.default)(FSCache, [{
    key: 'ensureDirExists',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return fs.mkdirp(this.dir);

              case 2:
                this.dirExists = true;

              case 3:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function ensureDirExists() {
        return _ref.apply(this, arguments);
      }

      return ensureDirExists;
    }()
  }, {
    key: 'getCacheFile',
    value: function getCacheFile(filename) {
      var hash = md5(this.optionsHash + filename);
      return path.join(this.dir, hash + '.json');
    }
  }, {
    key: 'writeDepMtimes',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(data) {
        var _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, dep, stats;

        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                // Write mtimes for each dependent file that is already compiled into this asset
                _iteratorNormalCompletion = true;
                _didIteratorError = false;
                _iteratorError = undefined;
                _context2.prev = 3;
                _iterator = (0, _getIterator3.default)(data.dependencies);

              case 5:
                if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
                  _context2.next = 15;
                  break;
                }

                dep = _step.value;

                if (!dep.includedInParent) {
                  _context2.next = 12;
                  break;
                }

                _context2.next = 10;
                return fs.stat(dep.name);

              case 10:
                stats = _context2.sent;

                dep.mtime = stats.mtime.getTime();

              case 12:
                _iteratorNormalCompletion = true;
                _context2.next = 5;
                break;

              case 15:
                _context2.next = 21;
                break;

              case 17:
                _context2.prev = 17;
                _context2.t0 = _context2['catch'](3);
                _didIteratorError = true;
                _iteratorError = _context2.t0;

              case 21:
                _context2.prev = 21;
                _context2.prev = 22;

                if (!_iteratorNormalCompletion && _iterator.return) {
                  _iterator.return();
                }

              case 24:
                _context2.prev = 24;

                if (!_didIteratorError) {
                  _context2.next = 27;
                  break;
                }

                throw _iteratorError;

              case 27:
                return _context2.finish(24);

              case 28:
                return _context2.finish(21);

              case 29:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this, [[3, 17, 21, 29], [22,, 24, 28]]);
      }));

      function writeDepMtimes(_x) {
        return _ref2.apply(this, arguments);
      }

      return writeDepMtimes;
    }()
  }, {
    key: 'write',
    value: function () {
      var _ref3 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3(filename, data) {
        return _regenerator2.default.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.prev = 0;
                _context3.next = 3;
                return this.ensureDirExists();

              case 3:
                _context3.next = 5;
                return this.writeDepMtimes(data);

              case 5:
                _context3.next = 7;
                return fs.writeFile(this.getCacheFile(filename), (0, _stringify2.default)(data));

              case 7:
                this.invalidated.delete(filename);
                _context3.next = 13;
                break;

              case 10:
                _context3.prev = 10;
                _context3.t0 = _context3['catch'](0);

                console.error('Error writing to cache', _context3.t0);

              case 13:
              case 'end':
                return _context3.stop();
            }
          }
        }, _callee3, this, [[0, 10]]);
      }));

      function write(_x2, _x3) {
        return _ref3.apply(this, arguments);
      }

      return write;
    }()
  }, {
    key: 'checkDepMtimes',
    value: function () {
      var _ref4 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee4(data) {
        var _iteratorNormalCompletion2, _didIteratorError2, _iteratorError2, _iterator2, _step2, dep, stats;

        return _regenerator2.default.wrap(function _callee4$(_context4) {
          while (1) {
            switch (_context4.prev = _context4.next) {
              case 0:
                // Check mtimes for files that are already compiled into this asset
                // If any of them changed, invalidate.
                _iteratorNormalCompletion2 = true;
                _didIteratorError2 = false;
                _iteratorError2 = undefined;
                _context4.prev = 3;
                _iterator2 = (0, _getIterator3.default)(data.dependencies);

              case 5:
                if (_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done) {
                  _context4.next = 16;
                  break;
                }

                dep = _step2.value;

                if (!dep.includedInParent) {
                  _context4.next = 13;
                  break;
                }

                _context4.next = 10;
                return fs.stat(dep.name);

              case 10:
                stats = _context4.sent;

                if (!(stats.mtime > dep.mtime)) {
                  _context4.next = 13;
                  break;
                }

                return _context4.abrupt('return', false);

              case 13:
                _iteratorNormalCompletion2 = true;
                _context4.next = 5;
                break;

              case 16:
                _context4.next = 22;
                break;

              case 18:
                _context4.prev = 18;
                _context4.t0 = _context4['catch'](3);
                _didIteratorError2 = true;
                _iteratorError2 = _context4.t0;

              case 22:
                _context4.prev = 22;
                _context4.prev = 23;

                if (!_iteratorNormalCompletion2 && _iterator2.return) {
                  _iterator2.return();
                }

              case 25:
                _context4.prev = 25;

                if (!_didIteratorError2) {
                  _context4.next = 28;
                  break;
                }

                throw _iteratorError2;

              case 28:
                return _context4.finish(25);

              case 29:
                return _context4.finish(22);

              case 30:
                return _context4.abrupt('return', true);

              case 31:
              case 'end':
                return _context4.stop();
            }
          }
        }, _callee4, this, [[3, 18, 22, 30], [23,, 25, 29]]);
      }));

      function checkDepMtimes(_x4) {
        return _ref4.apply(this, arguments);
      }

      return checkDepMtimes;
    }()
  }, {
    key: 'read',
    value: function () {
      var _ref5 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee5(filename) {
        var cacheFile, stats, cacheStats, json, data;
        return _regenerator2.default.wrap(function _callee5$(_context5) {
          while (1) {
            switch (_context5.prev = _context5.next) {
              case 0:
                if (!this.invalidated.has(filename)) {
                  _context5.next = 2;
                  break;
                }

                return _context5.abrupt('return', null);

              case 2:
                cacheFile = this.getCacheFile(filename);
                _context5.prev = 3;
                _context5.next = 6;
                return fs.stat(filename);

              case 6:
                stats = _context5.sent;
                _context5.next = 9;
                return fs.stat(cacheFile);

              case 9:
                cacheStats = _context5.sent;

                if (!(stats.mtime > cacheStats.mtime)) {
                  _context5.next = 12;
                  break;
                }

                return _context5.abrupt('return', null);

              case 12:
                _context5.next = 14;
                return fs.readFile(cacheFile);

              case 14:
                json = _context5.sent;
                data = JSON.parse(json);
                _context5.next = 18;
                return this.checkDepMtimes(data);

              case 18:
                if (_context5.sent) {
                  _context5.next = 20;
                  break;
                }

                return _context5.abrupt('return', null);

              case 20:
                return _context5.abrupt('return', data);

              case 23:
                _context5.prev = 23;
                _context5.t0 = _context5['catch'](3);
                return _context5.abrupt('return', null);

              case 26:
              case 'end':
                return _context5.stop();
            }
          }
        }, _callee5, this, [[3, 23]]);
      }));

      function read(_x5) {
        return _ref5.apply(this, arguments);
      }

      return read;
    }()
  }, {
    key: 'invalidate',
    value: function invalidate(filename) {
      this.invalidated.add(filename);
    }
  }, {
    key: 'delete',
    value: function () {
      var _ref6 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee6(filename) {
        return _regenerator2.default.wrap(function _callee6$(_context6) {
          while (1) {
            switch (_context6.prev = _context6.next) {
              case 0:
                _context6.prev = 0;
                _context6.next = 3;
                return fs.unlink(this.getCacheFile(filename));

              case 3:
                this.invalidated.delete(filename);
                _context6.next = 8;
                break;

              case 6:
                _context6.prev = 6;
                _context6.t0 = _context6['catch'](0);

              case 8:
              case 'end':
                return _context6.stop();
            }
          }
        }, _callee6, this, [[0, 6]]);
      }));

      function _delete(_x6) {
        return _ref6.apply(this, arguments);
      }

      return _delete;
    }()
  }]);
  return FSCache;
}();

module.exports = FSCache;
